@@ -1,7 +1,11 @@
 """CoolMasterNet platform to control of CoolMasterNet Climate Devices."""
+from __future__ import annotations
+
 import logging
 from typing import Any
 
+from pycoolmasternet_async import SWING_MODES
+
 from homeassistant.components.climate import (
     ClimateEntity,
     ClimateEntityFeature,
@@ -9,12 +13,12 @@ from homeassistant.components.climate import (
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import ATTR_TEMPERATURE, UnitOfTemperature
-from homeassistant.core import HomeAssistant, callback
-from homeassistant.helpers.entity import DeviceInfo
+from homeassistant.core import HomeAssistant
+from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
 from .const import CONF_SUPPORTED_MODES, DATA_COORDINATOR, DATA_INFO, DOMAIN
+from .entity import CoolmasterEntity
 
 CM_TO_HA_STATE = {
     "heat": HVACMode.HEAT,
@@ -31,60 +35,28 @@ FAN_MODES = ["low", "med", "high", "auto"]
 _LOGGER = logging.getLogger(__name__)
 
 
-def _build_entity(coordinator, unit_id, unit, supported_modes, info):
-    _LOGGER.debug("Found device %s", unit_id)
-    return CoolmasterClimate(coordinator, unit_id, unit, supported_modes, info)
-
-
 async def async_setup_entry(
     hass: HomeAssistant,
     config_entry: ConfigEntry,
-    async_add_devices: AddEntitiesCallback,
+    async_add_entities: AddEntitiesCallback,
 ) -> None:
     """Set up the CoolMasterNet climate platform."""
-    supported_modes = config_entry.data.get(CONF_SUPPORTED_MODES)
     info = hass.data[DOMAIN][config_entry.entry_id][DATA_INFO]
-
     coordinator = hass.data[DOMAIN][config_entry.entry_id][DATA_COORDINATOR]
-
-    all_devices = [
-        _build_entity(coordinator, unit_id, unit, supported_modes, info)
-        for (unit_id, unit) in coordinator.data.items()
-    ]
-
-    async_add_devices(all_devices)
-
-
-class CoolmasterClimate(CoordinatorEntity, ClimateEntity):
-    """Representation of a coolmaster climate device."""
-
-    _attr_supported_features = (
-        ClimateEntityFeature.TARGET_TEMPERATURE | ClimateEntityFeature.FAN_MODE
+    supported_modes = config_entry.data.get(CONF_SUPPORTED_MODES)
+    async_add_entities(
+        CoolmasterClimate(coordinator, unit_id, info, supported_modes)
+        for unit_id in coordinator.data
     )
 
-    def __init__(self, coordinator, unit_id, unit, supported_modes, info):
+
+class CoolmasterClimate(CoolmasterEntity, ClimateEntity):
+    """Representation of a coolmaster climate device."""
+
+    def __init__(self, coordinator, unit_id, info, supported_modes):
         """Initialize the climate device."""
-        super().__init__(coordinator)
-        self._unit_id = unit_id
-        self._unit = unit
+        super().__init__(coordinator, unit_id, info)
         self._hvac_modes = supported_modes
-        self._info = info
-
-    @callback
-    def _handle_coordinator_update(self):
-        self._unit = self.coordinator.data[self._unit_id]
-        super()._handle_coordinator_update()
-
-    @property
-    def device_info(self) -> DeviceInfo:
-        """Return device info for this device."""
-        return DeviceInfo(
-            identifiers={(DOMAIN, self.unique_id)},
-            manufacturer="CoolAutomation",
-            model="CoolMasterNet",
-            name=self.name,
-            sw_version=self._info["version"],
-        )
 
     @property
     def unique_id(self):
@@ -96,6 +68,16 @@ class CoolmasterClimate(CoordinatorEntity, ClimateEntity):
         """Return the name of the climate device."""
         return self.unique_id
 
+    @property
+    def supported_features(self) -> ClimateEntityFeature:
+        """Return the list of supported features."""
+        supported_features = (
+            ClimateEntityFeature.TARGET_TEMPERATURE | ClimateEntityFeature.FAN_MODE
+        )
+        if self.swing_mode:
+            supported_features |= ClimateEntityFeature.SWING_MODE
+        return supported_features
+
     @property
     def temperature_unit(self) -> str:
         """Return the unit of measurement."""
@@ -138,6 +120,16 @@ class CoolmasterClimate(CoordinatorEntity, ClimateEntity):
         """Return the list of available fan modes."""
         return FAN_MODES
 
+    @property
+    def swing_mode(self) -> str | None:
+        """Return the swing mode setting."""
+        return self._unit.swing
+
+    @property
+    def swing_modes(self) -> list[str] | None:
+        """Return swing modes if supported."""
+        return SWING_MODES if self.swing_mode is not None else None
+
     async def async_set_temperature(self, **kwargs: Any) -> None:
         """Set new target temperatures."""
         if (temp := kwargs.get(ATTR_TEMPERATURE)) is not None:
@@ -151,6 +143,15 @@ class CoolmasterClimate(CoordinatorEntity, ClimateEntity):
         self._unit = await self._unit.set_fan_speed(fan_mode)
         self.async_write_ha_state()
 
+    async def async_set_swing_mode(self, swing_mode: str) -> None:
+        """Set new swing mode."""
+        _LOGGER.debug("Setting swing mode of %s to %s", self.unique_id, swing_mode)
+        try:
+            self._unit = await self._unit.set_swing(swing_mode)
+        except ValueError as error:
+            raise HomeAssistantError(error) from error
+        self.async_write_ha_state()
+
     async def async_set_hvac_mode(self, hvac_mode: HVACMode) -> None:
         """Set new operation mode."""
         _LOGGER.debug("Setting operation mode of %s to %s", self.unique_id, hvac_mode)
