@@ -114,8 +114,10 @@ class HabitipyData:
         except ClientResponseError as error:
             if error.status == HTTPStatus.TOO_MANY_REQUESTS:
                 _LOGGER.warning(
-                    "Sensor data update for %s has too many API requests;"
-                    " Skipping the update",
+                    (
+                        "Sensor data update for %s has too many API requests;"
+                        " Skipping the update"
+                    ),
                     DOMAIN,
                 )
             else:
@@ -131,8 +133,10 @@ class HabitipyData:
             except ClientResponseError as error:
                 if error.status == HTTPStatus.TOO_MANY_REQUESTS:
                     _LOGGER.warning(
-                        "Sensor data update for %s has too many API requests;"
-                        " Skipping the update",
+                        (
+                            "Sensor data update for %s has too many API requests;"
+                            " Skipping the update"
+                        ),
                         DOMAIN,
                     )
                 else:
