@@ -15,13 +15,11 @@ from ..mixins import async_setup_entry_helper, warn_for_legacy_schema
 from .schema import CONF_SCHEMA, LEGACY, MQTT_VACUUM_SCHEMA, STATE
 from .schema_legacy import (
     DISCOVERY_SCHEMA_LEGACY,
-    PLATFORM_SCHEMA_LEGACY,
     PLATFORM_SCHEMA_LEGACY_MODERN,
     async_setup_entity_legacy,
 )
 from .schema_state import (
     DISCOVERY_SCHEMA_STATE,
-    PLATFORM_SCHEMA_STATE,
     PLATFORM_SCHEMA_STATE_MODERN,
     async_setup_entity_state,
 )
@@ -34,14 +32,6 @@ def validate_mqtt_vacuum_discovery(config_value: ConfigType) -> ConfigType:
     return config
 
 
-# Configuring MQTT Vacuums under the vacuum platform key was deprecated in HA Core 2022.6
-def validate_mqtt_vacuum(config_value: ConfigType) -> ConfigType:
-    """Validate MQTT vacuum schema (deprecated)."""
-    schemas = {LEGACY: PLATFORM_SCHEMA_LEGACY, STATE: PLATFORM_SCHEMA_STATE}
-    config: ConfigType = schemas[config_value[CONF_SCHEMA]](config_value)
-    return config
-
-
 def validate_mqtt_vacuum_modern(config_value: ConfigType) -> ConfigType:
     """Validate MQTT vacuum modern schema."""
     schemas = {
@@ -56,7 +46,8 @@ DISCOVERY_SCHEMA = vol.All(
     MQTT_VACUUM_SCHEMA.extend({}, extra=vol.ALLOW_EXTRA), validate_mqtt_vacuum_discovery
 )
 
-# Configuring MQTT Vacuums under the vacuum platform key was deprecated in HA Core 2022.6
+# Configuring MQTT Vacuums under the vacuum platform key was deprecated in
+# HA Core 2022.6
 # Setup for the legacy YAML format was removed in HA Core 2022.12
 PLATFORM_SCHEMA = vol.All(
     warn_for_legacy_schema(vacuum.DOMAIN),
@@ -72,7 +63,7 @@ async def async_setup_entry(
     config_entry: ConfigEntry,
     async_add_entities: AddEntitiesCallback,
 ) -> None:
-    """Set up MQTT vacuum through configuration.yaml and dynamically through MQTT discovery."""
+    """Set up MQTT vacuum through YAML and through MQTT discovery."""
     setup = functools.partial(
         _async_setup_entity, hass, async_add_entities, config_entry=config_entry
     )
