@@ -91,8 +91,7 @@ class PanasonicBluRay(MediaPlayerEntity):
         self._attr_media_duration = state[2]
 
     def turn_off(self) -> None:
-        """
-        Instruct the device to turn standby.
+        """Instruct the device to turn standby.
 
         Sending the "POWER" button will turn the device to standby - there
         is no way to turn it completely off remotely. However this works in
