@@ -68,8 +68,8 @@ class PandoraMediaPlayer(MediaPlayerEntity):
     """A media player that uses the Pianobar interface to Pandora."""
 
     _attr_media_content_type = MediaType.MUSIC
-    # MediaPlayerEntityFeature.VOLUME_SET is close to available but we need volume up/down
-    # controls in the GUI.
+    # MediaPlayerEntityFeature.VOLUME_SET is close to available
+    # but we need volume up/down controls in the GUI.
     _attr_supported_features = (
         MediaPlayerEntityFeature.PAUSE
         | MediaPlayerEntityFeature.TURN_ON
@@ -255,8 +255,7 @@ class PandoraMediaPlayer(MediaPlayerEntity):
 
     @util.Throttle(MIN_TIME_BETWEEN_UPDATES)
     def _update_song_position(self):
-        """
-        Get the song position and duration.
+        """Get the song position and duration.
 
         It's hard to predict whether or not the music will start during init
         so we have to detect state by checking the ticker.
@@ -312,8 +311,7 @@ class PandoraMediaPlayer(MediaPlayerEntity):
         self._pianobar.sendcontrol("m")  # do it twice in case an 'i' got in
 
     def _clear_buffer(self):
-        """
-        Clear buffer from pexpect.
+        """Clear buffer from pexpect.
 
         This is necessary because there are a bunch of 00:00 in the buffer
 
