@@ -19,6 +19,6 @@ async def async_get_config_entry_diagnostics(
 
     return {
         "config_entry": config_entry.as_dict(),
-        "data": coordinator.data,
+        "data": coordinator.gateway.get_data(),
         "debug": coordinator.gateway.get_debug(),
     }
