@@ -1,4 +1,4 @@
-"""Config flow for Whirlpool Sixth Sense integration."""
+"""Config flow for Whirlpool Appliances integration."""
 from __future__ import annotations
 
 import asyncio
@@ -6,21 +6,29 @@ from collections.abc import Mapping
 import logging
 from typing import Any
 
-import aiohttp
+from aiohttp import ClientError
 import voluptuous as vol
+from whirlpool.appliancesmanager import AppliancesManager
 from whirlpool.auth import Auth
-from whirlpool.backendselector import BackendSelector, Brand, Region
+from whirlpool.backendselector import BackendSelector
 
 from homeassistant import config_entries, core, exceptions
-from homeassistant.const import CONF_PASSWORD, CONF_USERNAME
+from homeassistant.const import CONF_PASSWORD, CONF_REGION, CONF_USERNAME
 from homeassistant.data_entry_flow import FlowResult
+from homeassistant.helpers.aiohttp_client import async_get_clientsession
 
-from .const import DOMAIN
+from .const import CONF_REGIONS_MAP, DOMAIN
+from .util import get_brand_for_region
 
 _LOGGER = logging.getLogger(__name__)
 
+
 STEP_USER_DATA_SCHEMA = vol.Schema(
-    {vol.Required(CONF_USERNAME): str, vol.Required(CONF_PASSWORD): str}
+    {
+        vol.Required(CONF_USERNAME): str,
+        vol.Required(CONF_PASSWORD): str,
+        vol.Required(CONF_REGION): vol.In(list(CONF_REGIONS_MAP)),
+    }
 )
 
 REAUTH_SCHEMA = vol.Schema({vol.Required(CONF_PASSWORD): str})
@@ -33,16 +41,24 @@ async def validate_input(
 
     Data has the keys from STEP_USER_DATA_SCHEMA with values provided by the user.
     """
-    backend_selector = BackendSelector(Brand.Whirlpool, Region.EU)
-    auth = Auth(backend_selector, data[CONF_USERNAME], data[CONF_PASSWORD])
+    session = async_get_clientsession(hass)
+    region = CONF_REGIONS_MAP[data[CONF_REGION]]
+    brand = get_brand_for_region(region)
+    backend_selector = BackendSelector(brand, region)
+    auth = Auth(backend_selector, data[CONF_USERNAME], data[CONF_PASSWORD], session)
     try:
         await auth.do_auth()
-    except (asyncio.TimeoutError, aiohttp.ClientConnectionError) as exc:
+    except (asyncio.TimeoutError, ClientError) as exc:
         raise CannotConnect from exc
 
     if not auth.is_access_token_valid():
         raise InvalidAuth
 
+    appliances_manager = AppliancesManager(backend_selector, auth, session)
+    await appliances_manager.fetch_appliances()
+    if appliances_manager.aircons is None and appliances_manager.washer_dryers is None:
+        raise NoAppliances
+
     return {"title": data[CONF_USERNAME]}
 
 
@@ -68,7 +84,7 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             assert self.entry is not None
             password = user_input[CONF_PASSWORD]
             data = {
-                CONF_USERNAME: self.entry.data[CONF_USERNAME],
+                **self.entry.data,
                 CONF_PASSWORD: password,
             }
 
@@ -110,6 +126,8 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             errors["base"] = "cannot_connect"
         except InvalidAuth:
             errors["base"] = "invalid_auth"
+        except NoAppliances:
+            errors["base"] = "no_appliances"
         except Exception:  # pylint: disable=broad-except
             _LOGGER.exception("Unexpected exception")
             errors["base"] = "unknown"
@@ -131,3 +149,7 @@ class CannotConnect(exceptions.HomeAssistantError):
 
 class InvalidAuth(exceptions.HomeAssistantError):
     """Error to indicate there is invalid auth."""
+
+
+class NoAppliances(exceptions.HomeAssistantError):
+    """Error to indicate no supported appliances in the user account."""
