@@ -10,7 +10,7 @@ timer.
 from __future__ import annotations
 
 from collections import UserDict
-from collections.abc import Callable, Iterable, Mapping
+from collections.abc import Callable, Iterable, Mapping, ValuesView
 import logging
 from typing import TYPE_CHECKING, Any, TypeVar, cast
 
@@ -30,6 +30,7 @@ from homeassistant.const import (
     MAX_LENGTH_STATE_ENTITY_ID,
     STATE_UNAVAILABLE,
     STATE_UNKNOWN,
+    EntityCategory,
     Platform,
 )
 from homeassistant.core import (
@@ -42,17 +43,17 @@ from homeassistant.core import (
 from homeassistant.exceptions import MaxLengthExceeded
 from homeassistant.loader import bind_hass
 from homeassistant.util import slugify, uuid as uuid_util
+from homeassistant.util.json import format_unserializable_data
 
 from . import device_registry as dr, storage
 from .device_registry import EVENT_DEVICE_REGISTRY_UPDATED
 from .frame import report
+from .json import JSON_DUMP, find_paths_unserializable_data
 from .typing import UNDEFINED, UndefinedType
 
 if TYPE_CHECKING:
     from homeassistant.config_entries import ConfigEntry
 
-    from .entity import EntityCategory
-
 T = TypeVar("T")
 
 DATA_REGISTRY = "entity_registry"
@@ -64,6 +65,13 @@ STORAGE_VERSION_MAJOR = 1
 STORAGE_VERSION_MINOR = 10
 STORAGE_KEY = "core.entity_registry"
 
+ENTITY_CATEGORY_VALUE_TO_INDEX: dict[EntityCategory | None, int] = {
+    # mypy does not understand strenum
+    val: idx  # type: ignore[misc]
+    for idx, val in enumerate(EntityCategory)
+}
+ENTITY_CATEGORY_INDEX_TO_VALUE = dict(enumerate(EntityCategory))
+
 # Attributes relevant to describing entity
 # to external services.
 ENTITY_DESCRIBING_ATTRIBUTES = {
@@ -96,6 +104,12 @@ class RegistryEntryHider(StrEnum):
 
 EntityOptionsType = Mapping[str, Mapping[str, Any]]
 
+DISLAY_DICT_OPTIONAL = (
+    ("ai", "area_id"),
+    ("di", "device_id"),
+    ("tk", "translation_key"),
+)
+
 
 @attr.s(slots=True, frozen=True)
 class RegistryEntry:
@@ -119,7 +133,8 @@ class RegistryEntry:
     has_entity_name: bool = attr.ib(default=False)
     name: str | None = attr.ib(default=None)
     options: EntityOptionsType = attr.ib(
-        default=None, converter=attr.converters.default_if_none(factory=dict)  # type: ignore[misc]
+        default=None,
+        converter=attr.converters.default_if_none(factory=dict),  # type: ignore[misc]
     )
     # As set by integration
     original_device_class: str | None = attr.ib(default=None)
@@ -129,6 +144,13 @@ class RegistryEntry:
     translation_key: str | None = attr.ib(default=None)
     unit_of_measurement: str | None = attr.ib(default=None)
 
+    _partial_repr: str | None | UndefinedType = attr.ib(
+        cmp=False, default=UNDEFINED, init=False, repr=False
+    )
+    _display_repr: str | None | UndefinedType = attr.ib(
+        cmp=False, default=UNDEFINED, init=False, repr=False
+    )
+
     @domain.default
     def _domain_default(self) -> str:
         """Compute domain value."""
@@ -144,6 +166,100 @@ class RegistryEntry:
         """Return if entry is hidden."""
         return self.hidden_by is not None
 
+    @property
+    def _as_display_dict(self) -> dict[str, Any] | None:
+        """Return a partial dict representation of the entry.
+
+        This version only includes what's needed for display.
+        Returns None if there's no data needed for display.
+        """
+        display_dict: dict[str, Any] = {"ei": self.entity_id, "pl": self.platform}
+        for key, attr_name in DISLAY_DICT_OPTIONAL:
+            if (attr_val := getattr(self, attr_name)) is not None:
+                display_dict[key] = attr_val
+        if (category := self.entity_category) is not None:
+            display_dict["ec"] = ENTITY_CATEGORY_VALUE_TO_INDEX[category]
+        if self.hidden_by is not None:
+            display_dict["hb"] = True
+        if not self.name and self.has_entity_name:
+            display_dict["en"] = self.original_name
+        if self.domain == "sensor" and (sensor_options := self.options.get("sensor")):
+            if (precision := sensor_options.get("display_precision")) is not None:
+                display_dict["dp"] = precision
+            elif (
+                precision := sensor_options.get("suggested_display_precision")
+            ) is not None:
+                display_dict["dp"] = precision
+        return display_dict
+
+    @property
+    def display_json_repr(self) -> str | None:
+        """Return a cached partial JSON representation of the entry.
+
+        This version only includes what's needed for display.
+        """
+        if self._display_repr is not UNDEFINED:
+            return self._display_repr
+
+        try:
+            dict_repr = self._as_display_dict
+            json_repr: str | None = JSON_DUMP(dict_repr) if dict_repr else None
+            object.__setattr__(self, "_display_repr", json_repr)
+        except (ValueError, TypeError):
+            object.__setattr__(self, "_display_repr", None)
+            _LOGGER.error(
+                "Unable to serialize entry %s to JSON. Bad data found at %s",
+                self.entity_id,
+                format_unserializable_data(
+                    find_paths_unserializable_data(dict_repr, dump=JSON_DUMP)
+                ),
+            )
+        # Mypy doesn't understand the __setattr__ business
+        return self._display_repr  # type: ignore[return-value]
+
+    @property
+    def as_partial_dict(self) -> dict[str, Any]:
+        """Return a partial dict representation of the entry."""
+        return {
+            "area_id": self.area_id,
+            "config_entry_id": self.config_entry_id,
+            "device_id": self.device_id,
+            "disabled_by": self.disabled_by,
+            "entity_category": self.entity_category,
+            "entity_id": self.entity_id,
+            "has_entity_name": self.has_entity_name,
+            "hidden_by": self.hidden_by,
+            "icon": self.icon,
+            "id": self.id,
+            "name": self.name,
+            "options": self.options,
+            "original_name": self.original_name,
+            "platform": self.platform,
+            "translation_key": self.translation_key,
+            "unique_id": self.unique_id,
+        }
+
+    @property
+    def partial_json_repr(self) -> str | None:
+        """Return a cached partial JSON representation of the entry."""
+        if self._partial_repr is not UNDEFINED:
+            return self._partial_repr
+
+        try:
+            dict_repr = self.as_partial_dict
+            object.__setattr__(self, "_partial_repr", JSON_DUMP(dict_repr))
+        except (ValueError, TypeError):
+            object.__setattr__(self, "_partial_repr", None)
+            _LOGGER.error(
+                "Unable to serialize entry %s to JSON. Bad data found at %s",
+                self.entity_id,
+                format_unserializable_data(
+                    find_paths_unserializable_data(dict_repr, dump=JSON_DUMP)
+                ),
+            )
+        # Mypy doesn't understand the __setattr__ business
+        return self._partial_repr  # type: ignore[return-value]
+
     @callback
     def write_unavailable_state(self, hass: HomeAssistant) -> None:
         """Write the unavailable state to the state machine."""
@@ -267,6 +383,10 @@ class EntityRegistryItems(UserDict[str, "RegistryEntry"]):
         self._entry_ids: dict[str, RegistryEntry] = {}
         self._index: dict[tuple[str, str, str], str] = {}
 
+    def values(self) -> ValuesView[RegistryEntry]:
+        """Return the underlying values to avoid __iter__ overhead."""
+        return self.data.values()
+
     def __setitem__(self, key: str, entry: RegistryEntry) -> None:
         """Add an item."""
         if key in self:
@@ -473,8 +593,6 @@ class EntityRegistry:
         ):
             disabled_by = RegistryEntryDisabler.INTEGRATION
 
-        from .entity import EntityCategory  # pylint: disable=import-outside-toplevel
-
         if (
             entity_category
             and entity_category is not UNDEFINED
@@ -638,8 +756,6 @@ class EntityRegistry:
         ):
             raise ValueError("hidden_by must be a RegistryEntryHider value")
 
-        from .entity import EntityCategory  # pylint: disable=import-outside-toplevel
-
         if (
             entity_category
             and entity_category is not UNDEFINED
@@ -780,8 +896,7 @@ class EntityRegistry:
         new_unique_id: str | UndefinedType = UNDEFINED,
         new_device_id: str | None | UndefinedType = UNDEFINED,
     ) -> RegistryEntry:
-        """
-        Update entity platform.
+        """Update entity platform.
 
         This should only be used when an entity needs to be migrated between
         integrations.
@@ -808,11 +923,18 @@ class EntityRegistry:
 
     @callback
     def async_update_entity_options(
-        self, entity_id: str, domain: str, options: dict[str, Any]
+        self, entity_id: str, domain: str, options: Mapping[str, Any] | None
     ) -> RegistryEntry:
-        """Update entity options."""
+        """Update entity options for a domain.
+
+        If the domain options are set to None, they will be removed.
+        """
         old = self.entities[entity_id]
-        new_options: EntityOptionsType = {**old.options, domain: options}
+        new_options = {
+            key: value for key, value in old.options.items() if key != domain
+        }
+        if options is not None:
+            new_options[domain] = options
         return self._async_update_entity(entity_id, options=new_options)
 
     async def async_load(self) -> None:
@@ -822,8 +944,6 @@ class EntityRegistry:
         data = await self._store.async_load()
         entities = EntityRegistryItems()
 
-        from .entity import EntityCategory  # pylint: disable=import-outside-toplevel
-
         if data is not None:
             for entity in data["entities"]:
                 # We removed this in 2022.5. Remove this check in 2023.1.
